@@ -6,7 +6,6 @@
 /* import-globals-from editBookmark.js */
 /* import-globals-from /toolkit/content/contentAreaUtils.js */
 /* import-globals-from /browser/components/downloads/content/allDownloadsView.js */
-/* import-globals-from /browser/base/content/utilityOverlay.js */
 
 /* Shared Places Import - change other consumers if you change this: */
 var { XPCOMUtils } = ChromeUtils.importESModule(
@@ -18,6 +17,7 @@ ChromeUtils.defineESModuleGetters(this, {
   PlacesBackups: "resource://gre/modules/PlacesBackups.sys.mjs",
   PrivateBrowsingUtils: "resource://gre/modules/PrivateBrowsingUtils.sys.mjs",
   DownloadUtils: "resource://gre/modules/DownloadUtils.sys.mjs",
+  DownloadsTorWarning: "resource:///modules/DownloadsTorWarning.sys.mjs",
 });
 XPCOMUtils.defineLazyScriptGetter(
   this,
@@ -158,15 +158,25 @@ var PlacesOrganizer = {
       "&sort=" +
       Ci.nsINavHistoryQueryOptions.SORT_BY_DATE_DESCENDING;
 
-    const torWarningMessage = document.getElementById(
-      "placesDownloadsTorWarning"
+    const torWarning = new DownloadsTorWarning(
+      document.getElementById("placesDownloadsTorWarning"),
+      true,
+      () => {
+        document
+          .getElementById("downloadsListBox")
+          .focus({ preventFocusRing: true });
+      }
     );
+    torWarning.activate();
+    window.addEventListener("unload", () => {
+      torWarning.deactivate();
+    });
+
     ContentArea.setContentViewForQueryString(
       DOWNLOADS_QUERY,
       () =>
         new DownloadsPlacesView(
           document.getElementById("downloadsListBox"),
-          torWarningMessage,
           false
         ),
       {
@@ -176,23 +186,6 @@ var PlacesOrganizer = {
       }
     );
 
-    // Intercept clicks on the tor warning tails link.
-    // NOTE: We listen for clicks on the parent instead of the
-    // <a data-l10n-name="tails-link"> element because the latter may be
-    // swapped for a new instance by Fluent when refreshing the parent.
-    document
-      .querySelector(".downloads-tor-warning-description")
-      .addEventListener("click", event => {
-        const tailsLink = event.target.closest(
-          ".downloads-tor-warning-tails-link"
-        );
-        if (!tailsLink) {
-          return;
-        }
-        event.preventDefault();
-        openWebLinkIn(tailsLink.href, "tab");
-      });
-
     ContentArea.init();
 
     this._places = document.getElementById("placesList");
@@ -457,6 +450,11 @@ var PlacesOrganizer = {
     if (!ContentArea.currentViewOptions.showDetailsPane) {
       return;
     }
+    // _fillDetailsPane is only invoked when the activeElement is a tree,
+    // there's no other case where we need to update the details pane. This
+    // means it's not possible that while some input field in the panel is
+    // focused we try to update the panel contents causing potential dataloss
+    // of the user's input.
     let view = PlacesUIUtils.getViewForNode(document.activeElement);
     if (view) {
       let selectedNodes = view.selectedNode
@@ -517,7 +515,7 @@ var PlacesOrganizer = {
     };
 
     fp.init(
-      window,
+      window.browsingContext,
       PlacesUIUtils.promptLocalization.formatValueSync(
         "places-bookmarks-import"
       ),
@@ -542,7 +540,7 @@ var PlacesOrganizer = {
     };
 
     fp.init(
-      window,
+      window.browsingContext,
       PlacesUIUtils.promptLocalization.formatValueSync(
         "places-bookmarks-export"
       ),
@@ -655,7 +653,7 @@ var PlacesOrganizer = {
         "places-bookmarks-restore-title",
         "places-bookmarks-restore-filter-name",
       ]);
-    fp.init(window, title, Ci.nsIFilePicker.modeOpen);
+    fp.init(window.browsingContext, title, Ci.nsIFilePicker.modeOpen);
     fp.appendFilter(filterName, RESTORE_FILEPICKER_FILTER_EXT);
     fp.appendFilters(Ci.nsIFilePicker.filterAll);
     fp.displayDirectory = backupsDir;
@@ -728,7 +726,7 @@ var PlacesOrganizer = {
         "places-bookmarks-backup-title",
         "places-bookmarks-restore-filter-name",
       ]);
-    fp.init(window, title, Ci.nsIFilePicker.modeSave);
+    fp.init(window.browsingContext, title, Ci.nsIFilePicker.modeSave);
     fp.appendFilter(filterName, RESTORE_FILEPICKER_FILTER_EXT);
     fp.defaultString = PlacesBackups.getFilenameForDate();
     fp.defaultExtension = "json";
@@ -747,32 +745,19 @@ var PlacesOrganizer = {
 
     let selectedNode = aNodeList.length == 1 ? aNodeList[0] : null;
 
-    // If an input within a panel is focused, force-blur it so its contents
-    // are saved
-    if (gEditItemOverlay.itemId != -1) {
-      var focusedElement = document.commandDispatcher.focusedElement;
-      if (
-        (HTMLInputElement.isInstance(focusedElement) ||
-          HTMLTextAreaElement.isInstance(focusedElement)) &&
-        /^editBMPanel.*/.test(focusedElement.parentNode.parentNode.id)
-      ) {
-        focusedElement.blur();
-      }
-
-      // don't update the panel if we are already editing this node unless we're
-      // in multi-edit mode
-      if (selectedNode) {
-        let concreteGuid = PlacesUtils.getConcreteItemGuid(selectedNode);
-        var nodeIsSame =
-          gEditItemOverlay.itemId == selectedNode.itemId ||
-          gEditItemOverlay._paneInfo.itemGuid == concreteGuid ||
-          (selectedNode.itemId == -1 &&
-            gEditItemOverlay.uri &&
-            gEditItemOverlay.uri == selectedNode.uri);
-        if (nodeIsSame && !infoBox.hidden && !gEditItemOverlay.multiEdit) {
-          return;
-        }
-      }
+    // Don't update the panel if it's already editing this node, unless we're
+    // in multi-edit mode.
+    if (
+      selectedNode &&
+      !gEditItemOverlay.multiEdit &&
+      ((gEditItemOverlay.concreteGuid &&
+        gEditItemOverlay.concreteGuid ==
+          PlacesUtils.getConcreteItemGuid(selectedNode)) ||
+        (!selectedNode.bookmarkGuid &&
+          gEditItemOverlay.uri &&
+          gEditItemOverlay.uri == selectedNode.uri))
+    ) {
+      return;
     }
 
     // Clean up the panel before initing it again.
@@ -1198,7 +1183,7 @@ var ViewMenu = {
         menuitem.setAttribute("type", "radio");
         menuitem.setAttribute("name", "columns");
         // This column is the sort key. Its item is checked.
-        if (column.getAttribute("sortDirection") != "") {
+        if (column.hasAttribute("sortDirection")) {
           menuitem.setAttribute("checked", "true");
         }
       } else if (type == "checkbox") {
@@ -1440,6 +1425,7 @@ var ContentArea = {
       oldView.associatedElement.hidden = true;
       aNewView.associatedElement.hidden = false;
 
+      // Hide the Tor warning when not in the downloads view.
       const isDownloads = aNewView.associatedElement.id === "downloadsListBox";
       const torWarningMessage = document.getElementById(
         "placesDownloadsTorWarning"
