@@ -54,12 +54,8 @@ var gTorCircuitPanel = {
   init() {
     this._isActive = true;
 
-    const { ConsoleAPI } = ChromeUtils.import(
-      "resource://gre/modules/Console.jsm"
-    );
-    this._log = new ConsoleAPI({
+    this._log = console.createInstance({
       prefix: "TorCircuitPanel",
-      maxLogLevel: "log",
       maxLogLevelPref: "browser.torcircuitpanel.loglevel",
     });
 
@@ -131,7 +127,7 @@ var gTorCircuitPanel = {
     document
       .getElementById("tor-circuit-new-circuit")
       .addEventListener("command", () => {
-        TorDomainIsolator.newCircuitForBrowser(gBrowser);
+        TorDomainIsolator.newCircuitForBrowser(gBrowser.selectedBrowser);
       });
 
     // Update the display just before opening.
@@ -209,8 +205,11 @@ var gTorCircuitPanel = {
 
   /**
    * Observe circuit changes.
+   *
+   * @param {nsISupports} subject Notification-specific data
+   * @param {string} topic The notification topic
    */
-  observe(subject, topic, data) {
+  observe(subject, topic) {
     switch (topic) {
       case this.TOR_CIRCUIT_TOPIC:
         // TODO: Maybe check if we actually need to do something earlier.
@@ -244,6 +243,8 @@ var gTorCircuitPanel = {
    * Note that this element instance may change whenever its parent element
    * (#tor-circuit-alias-label) is re-translated. Attributes should be copied to
    * the new instance.
+   *
+   * @returns {Element?}
    */
   get _aliasLink() {
     return this._panelElements.aliasLabel.querySelector(
@@ -315,12 +316,11 @@ var gTorCircuitPanel = {
       this._currentBrowserData.domain === domain &&
       this._currentBrowserData.scheme === scheme &&
       this._currentBrowserData.nodes.length === nodes.length &&
-      // If non-null, the fingerprints of the nodes match.
-      (!nodes ||
-        nodes.every(
-          (n, index) =>
-            n.fingerprint === this._currentBrowserData.nodes[index].fingerprint
-        ))
+      // The fingerprints of the nodes match.
+      nodes.every(
+        (n, index) =>
+          n.fingerprint === this._currentBrowserData.nodes[index].fingerprint
+      )
     ) {
       // No change.
       this._log.debug(
@@ -378,6 +378,7 @@ var gTorCircuitPanel = {
   /**
    * Get the tor onion address alias for the given domain.
    *
+   * @param {string} domain An .onion domain to query an alias for.
    * @returns {string} The alias domain, or null if it has no alias.
    */
   _getOnionAlias(domain) {
@@ -614,19 +615,10 @@ var gTorCircuitPanel = {
       } else {
         addressesEl.append(", ");
       }
+      // Use semantic <code> block for the ip addresses, so the content
+      // (especially punctuation) can be better interpreted by screen readers,
+      // if they support this.
       const ipEl = document.createElement("code");
-      // TODO: Current HTML-aam 1.0 specs map the <code> element to the "code"
-      // role.
-      // However, mozilla-central commented out this mapping in
-      // accessible/base/HTMLMarkupMap.h because the HTML-aam specs at the
-      // time did not do this.
-      // See hg.mozilla.org/mozilla-central/rev/51eebe7d6199#l2.12
-      //
-      // This was updated in mozilla bug 1834931, for ESR 128
-      //
-      // For now we explicitly add the role="code", but once this is fixed
-      // from mozilla-central we should remove this.
-      ipEl.setAttribute("role", "code");
       ipEl.classList.add("tor-circuit-ip-address");
       ipEl.textContent = ip;
       addressesEl.append(ipEl);
